@@ -1,11 +1,11 @@
 package Test::Spy::Method;
-$Test::Spy::Method::VERSION = '0.003';
+$Test::Spy::Method::VERSION = '0.004';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo;
-use Mooish::AttributeBuilder;
+use Mooish::AttributeBuilder -standard;
 use Carp qw(croak);
 
 has field '_throws' => (
